procedual macro sql-fun
Attribute Macros
- from_
table - fill table/view fields to struct
- sql_
query_ many - This macro attribute is used to ad-hoc query returning multiple rows from the database.
- sql_
query_ one - This macro attribute is used to ad-hoc query returing a single row from the database
- sql_
query_ opt - This macro attribute is used to ad-hoc query returing a optional single row from the database
- sql_
statement - This macro attribute is used to specify the SQL statement to be executed