Crate sql_fun

Crate sql_fun 

procedual macro sql-fun

Attribute Macros

from_table
fill table/view fields to struct
sql_query_many
This macro attribute is used to ad-hoc query returning multiple rows from the database.
sql_query_one
This macro attribute is used to ad-hoc query returing a single row from the database
sql_query_opt
This macro attribute is used to ad-hoc query returing a optional single row from the database
sql_statement
This macro attribute is used to specify the SQL statement to be executed